@@ -24,7 +24,7 @@ package Finance::Quote::Stooq;
 use strict;
 use warnings;
 
-use Encode qw(decode encode);
+use Encode qw(decode);
 use LWP::UserAgent;
 use HTTP::Request::Common;
 use HTTP::CookieJar::LWP ();
@@ -33,53 +33,38 @@ use HTML::TableExtract;
 use constant DEBUG => $ENV{DEBUG};
 use if DEBUG, 'Smart::Comments', '###';
 
-our $VERSION = '1.68_01'; # TRIAL VERSION
-
-our $DISPLAY    = 'Stooq - Warsaw Stock Exchange';
-our @LABELS     = qw/symbol name open high low last bid ask date currency method/;
-our $METHODHASH = {subroutine => \&stooq, 
-                   display => $DISPLAY, 
-                   labels => \@LABELS};
-
-sub methodinfo {
-    return ( 
-        stooq   => $METHODHASH,
-        europe  => $METHODHASH,
-        poland  => $METHODHASH,
-    );
-}
-
-sub labels { my %m = methodinfo(); return map {$_ => [@{$m{$_}{labels}}] } keys %m; }
-
-sub methods {
-  my %m = methodinfo(); return map {$_ => $m{$_}{subroutine} } keys %m;
-}
+our $VERSION = '1.58'; # VERSION
 
 my $STOOQ_URL = 'https://stooq.com/q/?s=';
 
+sub methods {
+  return (stooq  => \&stooq,
+          europe => \&stooq,
+          poland => \&stooq);
+}
+
+our @labels = qw/symbol name open high low last bid ask date currency method/;
+
 my %currencies_by_link = (
-  '?i=21' => "EUR", # Europe (€)
-  '?i=23' => "GBP", # United Kingdom (£)
-  '?i=25' => "HKD", # Hong Kong (HK$)
-  '?i=30' => "HUF", # Hungary (Ft)
-  '?i=39' => "JPY", # Japan (¥)
-  '?i=60' => "PLN", # Poland (zł)
-  '?i=77' => "USD", # United States ($)
+  '?i=23' => "GBP",
+  '?i=60' => "PLN",
+  '?i=77' => "USD",
+  '?i=89' => "ZAR",
 );
 
 my %currencies_by_symbol = (
-  '&pound;'  => "GBP", # United Kingdom (£)
-  'p.'       => "GBX", # United Kingdom (penny)
-  '&euro;'   => "EUR", # Europe (€)
-  "z\x{142}" => "PLN", # Poland (zł)
-  '$'        => "USD", # United States ($)
-  '&cent;'   => "USX", # United States (¢)
-  'HK$'      => "HKD", # Hong Kong (HK$)
-  '&yen;'    => "JPY", # Japan (¥)
-  'Ft'       => "HUF", # Hungary (Ft)
+  'p.' => "GBX",
+  '&pound;' => "GBP",
+  'z\x{142}' => "PLN",
+  '\$' => "USD",
+  '?i=89' => "ZAR",
 );
 
-### [<now>] Currencies by Symbol: %currencies_by_symbol
+sub labels { 
+  return (stooq  => \@labels,
+          europe => \@labels, 
+          poland => \@labels);
+}
 
 sub stooq {
 
@@ -90,7 +75,7 @@ sub stooq {
 #  my $ua = LWP::UserAgent->new(cookie_jar => $cj);
   my $ua = $quoter->user_agent();
   $ua->cookie_jar($cj);
-  $ua->default_header('Accept-Encoding' => 'deflate');
+  $ua->default_header('Accept_Encoding' => 'deflate');
   $ua->default_header('Accept-Language' => 'en-US,en;q=0.5');
 
   foreach my $stock (@stocks) {
@@ -130,27 +115,15 @@ sub stooq {
                                         attribs => { id => 't1' } );
       if (($te->parse($body)) && ($table = $te->first_table_found)) {
         (my $last) = $table->cell(0,0) =~ m|^.+>([\d\.]+)<|;
-
-        # usually currency is embedded in an A tag
-        #   curency default: td > b[> span_with_price] + "&nbsp;" + _a_linking_to_currency
-        #   curency USD/HUF: td > b > _a_linking_to_currency + "&nbsp;" + span_with_price
-        # except for commodities there's no A tag:
-        #   commodities:     td > b[> span_with_price] + "&nbsp;_currency_without_link_"
-        ### [<now>] Cell 0,0: $table->cell(0,0)
         (my $currlink) = $table->cell(0,0) =~ m|<a href=t/(\?i=\d+)>|;
-        if ( ($currlink) && ($currencies_by_link{$currlink}) ) {
+        if ( $currencies_by_link{$currlink} ) {
           $currency = $currencies_by_link{$currlink};
-        } else {
-          (my $currsymbol) = $table->cell(0,0)
-            =~ m#[\d\.]+</span></b>&nbsp;(.+)/(ozt|lb|t|gal|bbl|bu|mmBtu)#;
-          ### [<now>] CurrSymbol: $currsymbol
-          if ( ($currsymbol) && ($currencies_by_symbol{$currsymbol}) ) {
-            $currency = $currencies_by_symbol{$currsymbol};
-          }
         }
-
-        ### [<now>] Currency: $currency
-	
+        (my $currsymbol) = $table->cell(0,0)
+          =~ m|<a href=t/\?i=\d+>(\S+?)</a>|;
+        if ( $currencies_by_symbol{$currsymbol} ) {
+          $currency = $currencies_by_symbol{$currsymbol};
+        }
         (my $date) = $table->cell(0,1) =~ m|Date.+>(\d{4}-\d{2}-\d{2})<|;
         (my $high, my $low) = $table->cell(1,1)
           =~ m|.+>([\d\.]+)<.+>([\d\.]+)<|;
@@ -158,7 +131,7 @@ sub stooq {
         (my $bid) = $table->cell(4,0) =~ m|Bid.+>([\d\.]+)<|;
         (my $ask) = $table->cell(4,1) =~ m|Ask.+>([\d\.]+)<|;
         # If last and date are defined, save values in hash
-        if ( ($last) && ($date) && ($currency) ) {
+        if ( ($last) && ($date) ) {
           $info{ $stock, 'success' }  = 1;
           $info{ $stock, 'method' }   = 'stooq';
           $info{ $stock, 'name' }     = $name;
@@ -170,23 +143,14 @@ sub stooq {
           $info{ $stock, 'bid' }      = $bid if ($bid);
           $info{ $stock, 'ask' }      = $ask if ($ask);
           $quoter->store_date(\%info, $stock, { isodate => $date });
-          # Adjust/scale price data if currency is GBX (GBp) or USX (USc)
-          if ( ( $currency eq 'GBX' ) || ( $currency eq 'USX' ) ) {
+          # Adjust/scale price data if currency is GBX
+          if ( $currency eq 'GBX' ) {
             foreach my $field ( $quoter->default_currency_fields ) {
               next unless ( $info{ $stock, $field } );
               $info{ $stock, $field } =
                 $quoter->scale_field( $info{ $stock, $field }, 0.01 );
             }
-            if ( $info{ $stock, 'currency' } eq 'GBX' ) {
-              $info{ $stock, 'currency' } = 'GBP';
-            } else {
-              $info{ $stock, 'currency' } = 'USD';
-            }
           }
-        } else {
-          $info{ $stock, "success" } = 0;
-          $info{ $stock, "errormsg" } =
-            "Error retrieving quote for $stock. Could not parse HTML returned from $url.";
         }
       } else {
         $te->eof;
